@@ -4,7 +4,7 @@
  * Copyright (C) 2000-2001 Ximian, Inc.
  *
  * Written by: Bradford Hovinen <hovinen@ximian.com>,
- *             Richard Hestilow <hestilow@ximian.com>
+ *             Rachel Hestilow <hestilow@ximian.com>
  *             Seth Nickell     <snickell@stanford.edu>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -42,12 +42,18 @@
 
 enum
 {
-	TARGET_URI_LIST
+	TARGET_URI_LIST,
+	TARGET_COLOR,
+	TARGET_BGIMAGE,
+/*	TARGET_BACKGROUND_RESET*/  
 };
 
 static GtkTargetEntry drop_types[] =
 {
-	{"text/uri-list", 0, TARGET_URI_LIST}
+	{"text/uri-list", 0, TARGET_URI_LIST},
+	{ "application/x-color", 0, TARGET_COLOR },
+	{ "property/bgimage", 0, TARGET_BGIMAGE },
+/*	{ "x-special/gnome-reset-background", 0, TARGET_BACKGROUND_RESET }*/
 };
 
 static gint n_drop_types = sizeof (drop_types) / sizeof (GtkTargetEntry);
@@ -348,7 +354,7 @@ setup_dialog (GladeXML *dialog, GConfChangeSet *changeset, ApplierSet *set)
 	g_object_set_data (G_OBJECT (set->prefs), "color2-label", WID("color2_label"));
 
 	peditor = gconf_peditor_new_select_menu_with_enum
-		(changeset, BG_PREFERENCES_COLOR_SHADING_TYPE, WID ("border_shading"), bg_preferences_orientation_get_type (), NULL);
+		(changeset, BG_PREFERENCES_COLOR_SHADING_TYPE, WID ("border_shading"), bg_preferences_orientation_get_type (), TRUE, NULL);
 	g_signal_connect (peditor, "value-changed", (GCallback) peditor_value_changed, set);
 
 	peditor = gconf_peditor_new_color
@@ -363,7 +369,7 @@ setup_dialog (GladeXML *dialog, GConfChangeSet *changeset, ApplierSet *set)
 	g_signal_connect (peditor, "value-changed", (GCallback) peditor_value_changed, set);
 	
 	peditor = gconf_peditor_new_select_radio_with_enum
-		(changeset, BG_PREFERENCES_PICTURE_OPTIONS, gtk_radio_button_get_group (GTK_RADIO_BUTTON (WID ("radiobutton1"))), bg_preferences_wptype_get_type (), NULL);
+		(changeset, BG_PREFERENCES_PICTURE_OPTIONS, gtk_radio_button_get_group (GTK_RADIO_BUTTON (WID ("radiobutton1"))), bg_preferences_wptype_get_type (), TRUE, NULL);
 	g_signal_connect (peditor, "value-changed", (GCallback) peditor_value_changed, set);
 
 	/* Make sure preferences get applied to the preview */
@@ -389,7 +395,8 @@ create_dialog (ApplierSet *set)
 	GladeXML  *dialog;
 	GSList *group;
 	int i;
-	const gchar *labels[] = { N_("_Wallpaper"), N_("C_entered"), N_("_Scaled"), N_("S_tretched"), N_("_No Picture") };
+	const gchar *labels[] = { N_("_Wallpaper"), N_("C_entered"), N_("_Scaled"), N_("Stretc_hed"), N_("_No Picture") };
+	GtkWidget *label;
 
 	/* FIXME: What the hell is domain? */
 	dialog = glade_xml_new (GNOMECC_DATA_DIR "/interfaces/background-properties.glade", "prefs_widget", NULL);
@@ -423,21 +430,34 @@ create_dialog (ApplierSet *set)
 
 	g_slist_free (group);
 
+	label = gtk_label_new_with_mnemonic (_("_Picture"));
+	gtk_frame_set_label_widget (GTK_FRAME (WID ("picture_frame")),
+				    label);
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label),
+			  	       WID ("background_image_button"));
+	gtk_widget_show (label);
+
+	gtk_label_set_mnemonic_widget (GTK_LABEL (WID ("border_shading_label")),
+				       WID ("border_shading"));
+	gtk_label_set_mnemonic_widget (GTK_LABEL (WID ("color1_label")),
+				       WID ("color1"));
+	gtk_label_set_mnemonic_widget (GTK_LABEL (WID ("color2_label")),
+				       WID ("color2"));
+
 	return dialog;
 }
 
-/* Callback issued when a button is clicked on the dialog */
 
 static void
-dialog_button_clicked_cb (GtkDialog *dialog, gint response_id, GConfChangeSet *changeset) 
+cb_dialog_response (GtkDialog *dialog, gint response_id)
 {
-	switch (response_id) {
-	case GTK_RESPONSE_CLOSE:
+	if (response_id == GTK_RESPONSE_HELP)
+		capplet_help (GTK_WINDOW (dialog),
+			"wgoscustdesk.xml",
+			"goscustdesk-7");
+	else
 		gtk_main_quit ();
-		break;
-	}
 }
-
 /* Callback issued during drag movements */
 
 static gboolean
@@ -464,40 +484,63 @@ drag_data_received_cb (GtkWidget *widget, GdkDragContext *context,
 		       GtkSelectionData *selection_data,
 		       guint info, guint time, gpointer data)
 {
-	GList *list;
-	GList *uris;
+	GConfClient *client = gconf_client_get_default ();
 	ApplierSet *set = (ApplierSet*) data; 
 
-	if (info != TARGET_URI_LIST)
-		return;
-	
-	uris = gnome_vfs_uri_list_parse ((gchar *) selection_data->
-					 data);
-	for (list = uris; list; list = list->next)
+	if (info == TARGET_URI_LIST ||
+	    info == TARGET_BGIMAGE)
 	{
-		GnomeVFSURI *uri = (GnomeVFSURI *) list->data;
-		GConfEntry *entry;
-		GConfValue *value = gconf_value_new (GCONF_VALUE_STRING);
-		GConfClient *client = gconf_client_get_default ();
+		GList *uris;
+
+		g_print ("got %s\n", selection_data->data);
+		uris = gnome_vfs_uri_list_parse ((gchar *) selection_data->data);
+		/* Arbitrarily pick the first item */
+		if (uris != NULL && uris->data != NULL)
+		{
+			GnomeVFSURI *uri = (GnomeVFSURI *) uris->data;
+			GConfEntry *entry;
+			GConfValue *value = gconf_value_new (GCONF_VALUE_STRING);
+			
+			gconf_value_set_string (value, gnome_vfs_uri_get_path (uri));
+
+			/* Hmm, should we bother with changeset here? */
+			gconf_client_set (client, BG_PREFERENCES_PICTURE_FILENAME, value, NULL);
+			gconf_client_suggest_sync (client, NULL);
+
+			/* this isn't emitted by the peditors,
+			 * so we have to manually update */
+			/* FIXME: this can't be right!!!! -jrb */
+			entry = gconf_entry_new (BG_PREFERENCES_PICTURE_FILENAME, value);
+			bg_preferences_merge_entry (set->prefs, entry);
+			gconf_entry_free (entry);
+			gconf_value_free (value);
+
+			gconf_client_set_string (client, BG_PREFERENCES_PICTURE_OPTIONS, "wallpaper", NULL);
+		}
+		gnome_vfs_uri_list_free (uris);
+	} else if (info == TARGET_COLOR) {
+		guint16 *channels;
+		char *color_spec;
 		
-		gconf_value_set_string (value, gnome_vfs_uri_get_path (uri));
+		if (selection_data->length != 8 || selection_data->format != 16) {
+			return;
+		}
+        
+		channels = (guint16 *) selection_data->data;
+		color_spec = g_strdup_printf ("#%02X%02X%02X", channels[0] >> 8, channels[1] >> 8, channels[2] >> 8);
+		gconf_client_set_string (client, BG_PREFERENCES_PICTURE_OPTIONS, "none", NULL);
+		gconf_client_set_string (client, BG_PREFERENCES_COLOR_SHADING_TYPE, "solid", NULL);
+		gconf_client_set_string (client, BG_PREFERENCES_PRIMARY_COLOR, color_spec, NULL);
+		g_free (color_spec);
+	} else if (info == TARGET_BGIMAGE) {
 
-		/* Hmm, should we bother with changeset here? */
-		gconf_client_set (client, BG_PREFERENCES_PICTURE_FILENAME, value, NULL);
-		gconf_client_suggest_sync (client, NULL);
+	} else if (info == TARGET_URI_LIST) {
 
-		/* this isn't emitted by the peditors,
-		 * so we have to manually update */
-		entry = gconf_entry_new (BG_PREFERENCES_PICTURE_FILENAME, value);
-		bg_preferences_merge_entry (set->prefs, entry);
-		gconf_entry_free (entry);
-		gconf_value_free (value);
 	}
-
+	
 	if (GTK_WIDGET_REALIZED (bg_applier_get_preview_widget (set->appliers[n_enum_vals - 1])))
 		applier_set_redraw (set);
 
-	gnome_vfs_uri_list_free (uris);
 }
 
 int
@@ -520,7 +563,8 @@ main (int argc, char **argv)
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
-	gnome_program_init (argv[0], VERSION, LIBGNOMEUI_MODULE, argc, argv,
+	gnome_program_init ("gnome-background-properties", VERSION,
+			    LIBGNOMEUI_MODULE, argc, argv,
 			    GNOME_PARAM_POPT_TABLE, cap_options,
 			    NULL);
 
@@ -537,7 +581,8 @@ main (int argc, char **argv)
 		setup_dialog (dialog, NULL, set);
 
 		dialog_win = gtk_dialog_new_with_buttons
-			(_("Background properties"), NULL, -1,
+			(_("Background Preferences"), NULL, -1,
+			 GTK_STOCK_HELP, GTK_RESPONSE_HELP,
 			 GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
 			 NULL);
 
@@ -545,7 +590,9 @@ main (int argc, char **argv)
 		gtk_window_set_icon (GTK_WINDOW(dialog_win), pixbuf);
 		gdk_pixbuf_unref (pixbuf);
 
-		g_signal_connect (G_OBJECT (dialog_win), "response", (GCallback) dialog_button_clicked_cb, NULL);
+		g_signal_connect (G_OBJECT (dialog_win),
+				    "response",
+				    G_CALLBACK (cb_dialog_response), NULL);
 
 		gtk_drag_dest_set (dialog_win, GTK_DEST_DEFAULT_ALL,
 				   drop_types, n_drop_types,
