@@ -5,7 +5,7 @@
  * Copyright (C) 2001 Jonathan Blandford
  *
  * Written by: Bradford Hovinen <hovinen@ximian.com>
- *             Richard Hestilow <hestilow@ximian.com>
+ *             Rachel Hestilow <hestilow@ximian.com>
  *	       Jonathan Blandford <jrb@redhat.com>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -101,13 +101,13 @@ delay_to_widget (GConfPropertyEditor *peditor, const GConfValue *value)
 	new_value = gconf_value_new (GCONF_VALUE_INT);
 
 	if (delay >= (1000 + 700) / 2)
-		gconf_value_set_int (new_value, 0);
-	else if (delay >= (700 + 300) / 2)
-		gconf_value_set_int (new_value, 1);
-	else if (delay >= (300) / 2)
-		gconf_value_set_int (new_value, 2);
-	else
 		gconf_value_set_int (new_value, 3);
+	else if (delay >= (700 + 300) / 2)
+		gconf_value_set_int (new_value, 2);
+	else if (delay >= (300 + 150) / 2)
+		gconf_value_set_int (new_value, 1);
+	else
+		gconf_value_set_int (new_value, 0);
 
 	return new_value;
 }
@@ -116,7 +116,7 @@ static GConfValue *
 delay_from_widget (GConfPropertyEditor *peditor, GConfValue *value) 
 {
 	static int delays[] = {
-		1000, 700, 300, 0
+		150, 300, 700, 1000
 	};
 
 	GConfValue *new_value;
@@ -223,14 +223,19 @@ dialog_response (GtkWidget *widget,
 		 gint       response_id,
 		 GConfChangeSet *changeset)
 {
-	switch (response_id)
-	{
-	case RESPONSE_CLOSE:
-	case GTK_RESPONSE_DELETE_EVENT:
-	default:
+	if (response_id == GTK_RESPONSE_HELP)
+		capplet_help (GTK_WINDOW (widget),
+			"wgoscustdesk.xml",
+			"goscustperiph-2");
+	else
 		gtk_main_quit ();
-		break;
-	}
+}
+
+static void
+accessibility_button_clicked (GtkWidget *widget,
+			      gpointer   data)
+{
+	g_spawn_command_line_async ("gnome-accessibility-keyboard-properties", NULL);
 }
 
 static void
@@ -300,6 +305,8 @@ setup_dialog (GladeXML       *dialog,
 		 NULL);
 	g_signal_connect (G_OBJECT (WID ("bell_custom_radio")), "mnemonic_activate", (GCallback) mnemonic_activate, WID ("bell_custom_entry"));
 	g_signal_connect (G_OBJECT (WID ("keyboard_dialog")), "response", (GCallback) dialog_response, changeset);
+
+	g_signal_connect (G_OBJECT (WID ("accessibility_button")), "clicked", (GCallback) accessibility_button_clicked, NULL);
 }
 
 static void
@@ -316,11 +323,14 @@ get_legacy_settings (void)
 	COPY_FROM_LEGACY (int,  "/gnome/desktop/peripherals/keyboard/rate",          "/Desktop/Keyboard/rate=30");
 	COPY_FROM_LEGACY (int,  "/gnome/desktop/peripherals/keyboard/delay",         "/Desktop/Keyboard/delay=500");
 	COPY_FROM_LEGACY (int,  "/gnome/desktop/peripherals/keyboard/volume",        "/Desktop/Keyboard/clickvolume=0");
+#if 0
 	COPY_FROM_LEGACY (int,  "/gnome/desktop/peripherals/keyboard/bell_volume",   "/Desktop/Bell/percent=50");
+#endif
 	COPY_FROM_LEGACY (int,  "/gnome/desktop/peripherals/keyboard/bell_pitch",    "/Desktop/Bell/pitch=50");
 	COPY_FROM_LEGACY (int,  "/gnome/desktop/peripherals/keyboard/bell_duration", "/Desktop/Bell/duration=100");
 }
 
+#if 0
 static void
 setup_accessibility (GladeXML *dialog, GConfChangeSet *changeset)
 {
@@ -329,6 +339,7 @@ setup_accessibility (GladeXML *dialog, GConfChangeSet *changeset)
 	GtkWidget *page = setup_accessX_dialog (changeset, FALSE);
 	gtk_notebook_append_page (GTK_NOTEBOOK (notebook), page, label);
 }
+#endif
 
 int
 main (int argc, char **argv) 
@@ -353,7 +364,7 @@ main (int argc, char **argv)
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
-	gnome_program_init (argv[0], VERSION, LIBGNOMEUI_MODULE, argc, argv,
+	gnome_program_init ("gnome-keyboard-properties", VERSION, LIBGNOMEUI_MODULE, argc, argv,
 			    GNOME_PARAM_POPT_TABLE, cap_options,
 			    GNOME_PARAM_APP_DATADIR, GNOMECC_DATA_DIR,
 			    NULL);
@@ -370,9 +381,10 @@ main (int argc, char **argv)
 		changeset = NULL;
 		dialog = create_dialog ();
 		setup_dialog (dialog, changeset);
+#if 0
 		setup_accessibility (dialog, changeset);
-
-		gtk_widget_show_all (WID ("keyboard_dialog"));
+#endif
+		gtk_widget_show (WID ("keyboard_dialog"));
 		gtk_main ();
 	}
 
