@@ -66,15 +66,18 @@ sound_properties_destroy (GtkObject *object)
 	SoundProperties *props = SOUND_PROPERTIES (object);
 	int i;
 
-	g_hash_table_foreach (props->priv->hash, cleanup_cb, NULL);
-	g_hash_table_destroy (props->priv->hash);
+	if (props->priv != NULL) {
+		g_hash_table_foreach (props->priv->hash, cleanup_cb, NULL);
+		g_hash_table_destroy (props->priv->hash);
 
-	for (i = 0; i < props->priv->events->len; i++)
-		sound_event_unref (g_ptr_array_index (props->priv->events, i)); 
+		for (i = 0; i < props->priv->events->len; i++)
+			sound_event_free (g_ptr_array_index (props->priv->events, i)); 
 
-	g_ptr_array_free (props->priv->events, FALSE);
-	
-	g_free (props->priv);
+		g_ptr_array_free (props->priv->events, FALSE);
+		
+		g_free (props->priv);
+		props->priv = NULL;
+	}
 
 	if (GTK_OBJECT_CLASS (sound_properties_parent_class)->destroy)
 		GTK_OBJECT_CLASS (sound_properties_parent_class)->destroy (object);
@@ -307,12 +310,11 @@ sound_properties_add_event (SoundProperties *props, gchar *prefix,
 	gnome_config_push_prefix (path);
 	
 	event = sound_event_new ();
-	sound_event_ref (event);
 	sound_event_set_category (event, category);
 	sound_event_set_name (event, name);
 	if ((old = sound_properties_lookup_event (props, category, name)))
 	{
-		sound_event_unref (event);
+		sound_event_free (event);
 		event = old;
 	}
 
@@ -505,7 +507,7 @@ sound_properties_remove_event (SoundProperties *props, SoundEvent *event)
 	g_signal_emit (GTK_OBJECT (props),
 		       sound_properties_signals[EVENT_REMOVED], 0,
 		       event);
-	sound_event_unref (event);
+	sound_event_free (event);
 }
 
 void
